@@ -16,6 +16,11 @@ class MyrtDeskDomain:
         """Current domain code"""
         return self._domain_code
 
+    async def send_command_raw(self, payload: list) -> List[int]:
+        """Sends raw command to MyrtDesk"""
+        resp = await self._transport.send_command([self._domain_code, *payload])
+        return resp
+
     async def send_command(self, payload: list) -> List[int]:
         """Sends command to MyrtDesk"""
         resp = await self._transport.send_request([self._domain_code, *payload])
