@@ -4,3 +4,5 @@ DOMAIN_LEGS = 2
 
 COMMAND_READ_HEIGHT = 0
 COMMAND_SET_HEIGHT = 1
+COMMAND_GET_SENSOR_LENGTH = 2
+COMMAND_CALIBRATE = 3
